
- [💼  About Recruitee](#--about-Recruitee)
- [😍 **What makes this major news for Recruitee customers \& partners?**](#-what-makes-this-major-news-for-Recruitee-customers--partners)
- [🔧 How does it work?](#-how-does-it-work)
  - [📊 Data integration capabilities:](#-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#-connector-actions)
- [🐍 Quick Start Examples](#-quick-start-examples)
- [🔗 Useful Links](#-useful-links)
- [🙏 Special Thanks](#-special-thanks)

# 💼  About Recruitee 

Recruitee is an innovative and intuitive recruitment software that empowers businesses to streamline hiring processes and attract top talent.

Recruitee provides a comprehensive solution that ensures a seamless and efficient recruitment experience.

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/3457716c-0c60-4db3-8f6d-78c6a42b9923 width=90% height=100% >
</p>

# 😍 **What makes this major news for Recruitee customers & partners?**

This new connector will enable Recruitee customers & partners to:
- ⚡ Seamlessly Integrate Talent & Workforce data
- 🤖 Elevate their Talent and Recruiter Experiences  
  
# 🔧 How does it work?
  
## 📊 Data integration capabilities:

- ➡️ Push Profiles from a Source of your choice to Recruitee
- ⬅️ Pull Jobs from Recruitee to a Destination of your choice

## 🧠 Artificial Intelligence capabilities:
  
- Easily Extract, Structure, and Categorize Talent & Workforce data
- Effortlessly Search, Score, and Match Profiles and Jobs with precision.

# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Push profile**](docs/push_profile.md) | Writes a profile from Hrflow.ai Source as a candidate on Recruitee via the API |
| [**Pull job list**](docs/pull_job_list.md) | Retrieves all jobs via the ***Recruitee*** API and send them to a ***Hrflow.ai Board***. |


</p>

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/ff726feb-d580-40f8-82b2-6c1132cebd8e width=90% height=100% >
</p>

# 🐍 Quick Start Examples


To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.
To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :


<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/44360e84-ec0c-49a1-81dd-799840613c6a width=90% height=100% >
</p>

Once the connector module is imported, you can leverage all the different actions that it offers. 

For more code details checkout connector code 

# 🔗 Useful Links

- 📄Visit [Recruitee](https://Recruitee.com/) to learn more.
- ⚙️ API documentation : [Recruitee API](https://api.recruitee.com/docs/index.html)
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/recruitee) on our Github.


# 🙏 Special Thanks  
- 💻 HrFlow.ai :  [Nedhir EBNOU](https://github.com/nedhirouebnou) - Software Engineer
- 🤝 Recruitee : **MengJia de Lange-Chen - Technical Partner Manager** and all the Recruitee team for their help and collaboration in building this integration
 
